#
# spec file for package sar2
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           sar2
Version:        2.5.0
Release:        2.4
Summary:        Rescue Helicopter Simulator
License:        GPL-2.0-only
Group:          Amusements/Games/3D/Simulation
URL:            https://searchandrescue2.github.io/sar2/
Source:         https://github.com/SearchAndRescue2/sar2/archive/v%{version}.tar.gz
BuildRequires:  Mesa-devel
BuildRequires:  fdupes
BuildRequires:  freealut-devel
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  libXxf86vm-devel
BuildRequires:  libvorbis-devel
BuildRequires:  openal-soft-devel
BuildRequires:  scons
BuildRequires:  xorg-x11-libICE-devel
BuildRequires:  xorg-x11-libSM-devel
BuildRequires:  xorg-x11-libX11-devel
BuildRequires:  xorg-x11-libXext-devel
BuildRequires:  xorg-x11-libXmu-devel
BuildRequires:  xorg-x11-libXpm-devel
Requires:       %{name}-data = %{version}
%if 0%{?suse_version} < 1330
Requires(post): update-desktop-files
Requires(postun): update-desktop-files
%endif

%description
Search and Rescue II (SaR II) is an open source helicopter simulator game for
Linux and OSX. In it you can fly several helicopter and airplane models in
some basic scenarios.

SaR II has low graphic requirements while still provides a fun and demanding
gameplay where the player needs to locate, pick-up and rescue victims of all
sorts in steep mountains, burning buildings or in the sea.

%package data
Summary:        Data files for sar2
Group:          Amusements/Games/3D/Simulation
Requires:       %{name} = %{version}
BuildArch:      noarch

%description data
Data files for Search and Rescue II

%prep
%setup -q

%build
scons --optflags="%{optflags} -DHAVE_LIBXPM"

%install
mkdir -p %{buildroot}%{_datadir}/%{name}
cp -ar data/* %{buildroot}%{_datadir}/%{name}/

mkdir -p %{buildroot}%{_mandir}/man6
cp -a man/* %{buildroot}%{_mandir}/man6

mkdir -p %{buildroot}%{_bindir}
cp -a bin/%{name} %{buildroot}%{_bindir}

install -D -m 0644 extra/sar2.desktop %{buildroot}%{_datadir}/applications/%{name}.desktop

install -D -m 0644 extra/sar2.xpm %{buildroot}%{_datadir}/pixmaps/%{name}.xpm

install -D -m 0644 extra/sar2.appdata.xml %{buildroot}%{_datadir}/appdata/%{name}.appdata.xml

%fdupes %{buildroot}%{_datadir}

%if 0%{?suse_version} < 1330
%post
%desktop_database_post

%postun
%desktop_database_postun
%endif

%files
%doc AUTHORS CHANGELOG.md HACKING README.md
%license LICENSE
%{_mandir}/man6/%{name}.6%{?ext_man}
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.xpm
%{_datadir}/appdata/%{name}.appdata.xml

%files data
%{_datadir}/%{name}/

%changelog
* Wed Nov  9 2022 Dmitriy Perlow <dap.darkness@gmail.com>
- BuildRequre sdl2 stuff via pkgconfig(*).
* Sun Jun 21 2020 code@hector.link
- Update to version 2.5.0:
  * Add preliminary OSX support.
  * Improve lagging on touch-down event.
  * Fix crash when loading Free Flight mode.
  * Add wind support and aerodynamic drag.
  * Add 2 training missions in windy weather.
  * Add support for wind gusts.
  * Rework airplane physics and stalling conditions.
  * Adjust models for more realistic speed and service ceiling conditions.
  * Allow a minimum helicopter throotle to 25%% (previously it was 50%%).
  * Let smoke be carried by the wind.
  * Add a switch in simulation options to enable/disable Wind.
  * Add wind conditions to all Guadarrama missions.
* Sun Apr 26 2020 code@hector.link
- Update to version 2.4.0:
  * Improvements to the Joystick system, adding new Rudder+Brakes mode, moving to libSDL2 and cleaning up unused menu settings.
  * Fix lagging when aircraft is landed.
  * Honor wheel brake coefficient.
* Tue Jun 12 2018 antoine.belvire@opensuse.org
- Update to version 2.3.3:
  * Upstream some patches submitted by contributors to facilitate
    the package build process.
  * Fix a number of old urls to point to the Github location.
- Drop upstreamed patches:
  * appdata.patch.
  * sar2-2.3.2-optflags.patch.
- Clean spec file.
* Sat Jul 15 2017 mailaender@opensuse.org
- Update to version 2.3.2
- Add appdata.xml
- Build with optflags
* Thu Jan 17 2013 joop.boonen@opensuse.org
- Fixed the spec file to be able to build for openSUSE > 12.2
* Fri Dec  2 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
* Fri Dec  2 2011 jreidinger@suse.com
- fix building (libs.patch)
* Mon Jun 13 2011 prusnak@opensuse.org
- split off data subpackage
* Mon Jun 13 2011 prusnak@opensuse.org
- spec cleanup
* Sun Apr 24 2011 hector1987@gmail.com
- initial build (v 2.3.0)
